package de.wenzlaff.bibelleseplan;

import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.time.format.DateTimeParseException;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

import de.wenzlaff.twbibel.Bibelbuecher;

/**
 * Die Programm Parameter für den Kommandozeilen Client.
 * 
 * @author Thomas Wenzlaff
 */
public class Parameter {

	private static final Logger LOG = LogManager.getLogger(Parameter.class.getName());

	private LocalDate startDatum;

	private Bibelbuecher bibelbuch;

	public LocalDate getStartDatum() {
		return startDatum;
	}

	/**
	 * Setzt das Start Datum oder wenn ungültig dann mit Tagesdatum
	 * 
	 * @param startDatum
	 */
	public void setStartDatum(String startDatum) {
		try {
			this.startDatum = LocalDate.parse(startDatum);
		} catch (DateTimeParseException e) {
			LOG.info("Kann das start Datum nicht parsen, setze das Tagesdatum.");
			this.startDatum = LocalDate.now();
			LOG.info("Termin ab Tagesdatum: " + this.startDatum.format(DateTimeFormatter.ISO_DATE));
		}
	}

	public Bibelbuecher getBibelbuch() {
		return bibelbuch;
	}

	public void setBibelbuch(String bibelbuch) {
		try {
			if (bibelbuch != null) {
				this.bibelbuch = Bibelbuecher.valueOf(bibelbuch);
			} else {
				this.bibelbuch = null;
			}
		} catch (IllegalArgumentException e) {
			LOG.error("Ungültiges Bibelbuch: " + bibelbuch + " Es sind nur diese Bücher gültig: " + Bibelbuecher.getAlleBibelbuecher());
		}
	}

	@Override
	public String toString() {
		StringBuilder builder = new StringBuilder();
		builder.append("Parameter [");
		if (startDatum != null) {
			builder.append("startDatum=");
			builder.append(startDatum);
			builder.append(", ");
		}
		if (bibelbuch != null) {
			builder.append("bibelbuch=");
			builder.append(bibelbuch);
		}
		builder.append("]");
		return builder.toString();
	}

}
